@@ -94,7 +94,8 @@ def split_rows_into_pages(data_as_rows: List[List[Union[str, int]]], no_of_row_p
 
 
 def generate_graphic(data_as_rows: List[List[Union[str, int]]] = (), header_texts: List[str] = HEADER_TEXTS, label_texts: List[str] = LABEL_TEXTS,
-                     number_texts: List[str] = NUMBER_TEXTS, date_texts: List[str] = DATE_TEXTS, guideline_text: str = GUIDELINE_TEXT) -> Image:
+                     number_texts: List[str] = NUMBER_TEXTS, date_texts: List[str] = DATE_TEXTS, guideline_text: str = GUIDELINE_TEXT,
+                     sd_color_below: str = "#eb4d3d", sd_color_above: str = "#aad73e") -> Image:
     with Image.open(TEMPLATE_IMG_PATH) as img:
         W, H = img.size
         # print(f"Template size = {W}, {H}")
@@ -150,7 +151,7 @@ def generate_graphic(data_as_rows: List[List[Union[str, int]]] = (), header_text
 
                 box_multiply_factor = 8
                 if row[4] < 0:
-                    box_color = "#eb4d3d"
+                    box_color = sd_color_below
                     text_offset = -24
                     text_anchor = "rs"
                 else:
@@ -166,11 +167,11 @@ def generate_graphic(data_as_rows: List[List[Union[str, int]]] = (), header_text
                 canvas.text((4390, 666 + 116 * i), row[6], font=CATEGORY_FONT, fill="#4e2a82", anchor="rs")  # 2 %
 
                 if row[7] < 0:
-                    box_color = "#eb4d3d"
+                    box_color = sd_color_below
                     text_offset = -24
                     text_anchor = "rs"
                 else:
-                    box_color = "#aad73e"
+                    box_color = sd_color_above
                     text_offset = 24
                     text_anchor = "ls"
                 canvas.rectangle((4788 + (_rescale_box_sd(row[7]) * box_multiply_factor), 692 + 116 * (i - 1), 4788, 692 + 116 * (i) + 4), fill=box_color,
